@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.1.7'
+version = '1.1.8'
 
 ###############################################################################
 # Some Imports
@@ -219,7 +219,7 @@ class Perturbations(object):
 
 
         #A list of available HMF fitting functions and their identifiers
-        self.mf_fits = ["PS", "ST", "Warren", "Jenkins", "Reed03", "Reed07", "Angulo", "Angulo_Bound", "Tinker",
+        self.mf_fits = ["PS", "ST", "SMT", "Warren", "Jenkins", "Reed03", "Reed07", "Angulo", "Angulo_Bound", "Tinker",
                         "Watson_FoF", "Watson", "Crocce", "Courtin", "Bhattacharya", "Behroozi", "user_model",
                         "Peacock"]
 
